package
Version:
v0.0.0-...-e3e3546
Opens a new window with list of versions in this module.
Published: Dec 18, 2025
License: BSD-3-Clause
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
const (
ActionInvalid Action = ""
ActionInclude Action = "include"
ActionExclude Action = "exclude"
)
type Filter struct {
Action Action
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.